Create a single styled radio button using Designsystemet styles. This is
the building block used by ds_radio_group() — a standalone ds_radio()
is not reactive on its own. To get a Shiny input value out of a group of
radio buttons, use ds_radio_group() instead.
Arguments
- inputId
The
id/forpair linking this radio to its label- label
The radio button label
- value
The value for this radio button
- name
The name grouping radio buttons together
- checked
If TRUE, this radio is initially selected
- size
Size variant ("sm", "md", "lg")
- disabled
If TRUE, disables the radio button
- ...
Additional attributes