Change the current page or total pages from the server.
Usage
update_ds_pagination(
session = shiny::getDefaultReactiveDomain(),
inputId,
current = NULL,
total = NULL
)Change the current page or total pages from the server.
update_ds_pagination(
session = shiny::getDefaultReactiveDomain(),
inputId,
current = NULL,
total = NULL
)