Change the selected value or choices from the server.
Usage
update_ds_select(
session = shiny::getDefaultReactiveDomain(),
inputId,
value = NULL,
choices = NULL
)Change the selected value or choices from the server.
update_ds_select(
session = shiny::getDefaultReactiveDomain(),
inputId,
value = NULL,
choices = NULL
)