| ds_radio | R Documentation |
Create a single styled radio button using Designsystemet styles. This is
the building block used by ds_radio_group() — a standalone ds_radio()
is not reactive on its own. To get a Shiny input value out of a group of
radio buttons, use ds_radio_group() instead.
ds_radio(
inputId,
label,
value,
name,
checked = FALSE,
size = NULL,
disabled = FALSE,
...
)
inputId |
The |
label |
The radio button label |
value |
The value for this radio button |
name |
The name grouping radio buttons together |
checked |
If TRUE, this radio is initially selected |
size |
Size variant ("sm", "md", "lg") |
disabled |
If TRUE, disables the radio button |
... |
Additional attributes |
A Shiny tag object
ds_radio("opt_a", label = "Option A", value = "a", name = "opts")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.